summaryrefslogtreecommitdiff
path: root/svx/source/engine3d/dragmt3d.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-08-22 14:54:18 +0200
committerNoel Grandin <noel@peralex.com>2016-08-23 09:54:16 +0200
commit6fc92adb8f89e653fd733e77ab24b4fcffe6a909 (patch)
tree398e14591cdfb44fb146def9eab0ccfa3fe720d3 /svx/source/engine3d/dragmt3d.cxx
parentc3b305149efd8a2407078ce5908ab1e1df567aba (diff)
convert SdrHdlKind to scoped enum
Change-Id: Ib0a06d94f8b51cce1f29f20d1c00d54be939c076
Diffstat (limited to 'svx/source/engine3d/dragmt3d.cxx')
-rw-r--r--svx/source/engine3d/dragmt3d.cxx30
1 files changed, 15 insertions, 15 deletions
diff --git a/svx/source/engine3d/dragmt3d.cxx b/svx/source/engine3d/dragmt3d.cxx
index 6083bd7441b4..640170ce9509 100644
--- a/svx/source/engine3d/dragmt3d.cxx
+++ b/svx/source/engine3d/dragmt3d.cxx
@@ -441,39 +441,39 @@ E3dDragMove::E3dDragMove(SdrDragView &_rView,
{
switch(meWhatDragHdl)
{
- case HDL_LEFT:
+ case SdrHdlKind::Left:
maScaleFixPos = maFullBound.RightCenter();
break;
- case HDL_RIGHT:
+ case SdrHdlKind::Right:
maScaleFixPos = maFullBound.LeftCenter();
break;
- case HDL_UPPER:
+ case SdrHdlKind::Upper:
maScaleFixPos = maFullBound.BottomCenter();
break;
- case HDL_LOWER:
+ case SdrHdlKind::Lower:
maScaleFixPos = maFullBound.TopCenter();
break;
- case HDL_UPLFT:
+ case SdrHdlKind::UpperLeft:
maScaleFixPos = maFullBound.BottomRight();
break;
- case HDL_UPRGT:
+ case SdrHdlKind::UpperRight:
maScaleFixPos = maFullBound.BottomLeft();
break;
- case HDL_LWLFT:
+ case SdrHdlKind::LowerLeft:
maScaleFixPos = maFullBound.TopRight();
break;
- case HDL_LWRGT:
+ case SdrHdlKind::LowerRight:
maScaleFixPos = maFullBound.TopLeft();
break;
default:
// Moving the object, HDL_MOVE
break;
}
// Override when IsResizeAtCenter()
if(getSdrDragView().IsResizeAtCenter())
{
- meWhatDragHdl = HDL_USER;
+ meWhatDragHdl = SdrHdlKind::User;
maScaleFixPos = maFullBound.Center();
}
}
@@ -487,7 +487,7 @@ void E3dDragMove::MoveSdrDrag(const Point& rPnt)
if(DragStat().CheckMinMoved(rPnt))
{
- if(HDL_MOVE == meWhatDragHdl)
+ if(SdrHdlKind::Move == meWhatDragHdl)
{
// Translation
// Determine the motion vector
@@ -605,13 +605,13 @@ void E3dDragMove::MoveSdrDrag(const Point& rPnt)
// constraints?
switch(meWhatDragHdl)
{
- case HDL_LEFT:
- case HDL_RIGHT:
+ case SdrHdlKind::Left:
+ case SdrHdlKind::Right:
// to constrain on X -> Y equal
aScNext.setY(aScFixPos.getY());
break;
- case HDL_UPPER:
- case HDL_LOWER:
+ case SdrHdlKind::Upper:
+ case SdrHdlKind::Lower:
// constrain to auf Y -> X equal
aScNext.setX(aScFixPos.getX());
break;
@@ -441,39 +441,39 @@ E3dDragMove::E3dDragMove(SdrDragView &_rView,
break;
default:
- // Moving the object, HDL_MOVE
+ // Moving the object, SdrHdlKind::Move
break;
}